pub fn parse_chat_meta(json: &str, session_id: String) -> Result<CursorSession>Expand description
Parse Cursor chat meta.json into a session.
Errors
Returns an error when the JSON is invalid, cwd is empty, or a timestamp is out of range.
pub fn parse_chat_meta(json: &str, session_id: String) -> Result<CursorSession>Parse Cursor chat meta.json into a session.
Returns an error when the JSON is invalid, cwd is empty, or a timestamp is out of range.